@@ -157,12 +157,11 @@ class iBootDriverInfo(PrefixedDriverInfo):
 
 DRIVER_INFO = {
     # production drivers
-    '.*_ipmi(tool|native)': PrefixedDriverInfo('ipmi'),
+    '.*_ipmi(tool|native)': PrefixedDriverInfo('ipmi', has_port=True),
     '.*_drac': PrefixedDriverInfo('drac', address_field='host'),
     '.*_ilo': PrefixedDriverInfo('ilo'),
     '.*_ucs': PrefixedDriverInfo(
         'ucs',
-        address_field='hostname',
         deprecated_mapping={
             'pm_service_profile': 'ucs_service_profile'
         }),
